#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2024/10/23
# @Author  : jiangwen04
# @File    : cv_algo_config.py
"""
from gaea_operator.config import OCRNetConfig, \
    PPYOLOEPLUSMConfig, \
    CoDETRConfig, SVTRLCNetConfig, DBNetConfig, ResNetConfig
from gaea_operator.metric.types.metric import SEMANTIC_SEGMENTATION_MIOU_METRIC_NAME, \
    BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME, OCR_ACCURACY_METRIC_NAME, \
    HMEAN_METRIC_NAME, CLASSIFICATION_ACCURACY_METRIC_NAME, \
    LOSS_METRIC_NAME, MIOU_METRIC_NAME, PACC_METRIC_NAME
from gaea_operator.utils import ModelTemplate

ALGORITH_TO_METRIC = {
    ModelTemplate.OCRNET_NAME: SEMANTIC_SEGMENTATION_MIOU_METRIC_NAME,
    ModelTemplate.PPYOLOE_PLUS_NAME: BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME,
    ModelTemplate.CODETR_NAME: BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME,
    ModelTemplate.CHANGE_OCRNET_NAME: SEMANTIC_SEGMENTATION_MIOU_METRIC_NAME,
    ModelTemplate.CHANGE_PPYOLOE_PLUS_NAME: BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME,
    ModelTemplate.SVTR_LCNET_NAME: OCR_ACCURACY_METRIC_NAME,
    ModelTemplate.DBNET_NAME: HMEAN_METRIC_NAME,
    ModelTemplate.CV_RESNET_NAME: CLASSIFICATION_ACCURACY_METRIC_NAME,
    ModelTemplate.MASKFORMER_NAME: PACC_METRIC_NAME,
    ModelTemplate.RESNET_NAME: CLASSIFICATION_ACCURACY_METRIC_NAME,

}

ALGORITH_TO_METRICS = {
    ModelTemplate.OCRNET_NAME: SEMANTIC_SEGMENTATION_MIOU_METRIC_NAME,
    ModelTemplate.PPYOLOE_PLUS_NAME: BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME,
    ModelTemplate.CODETR_NAME: BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME,
    ModelTemplate.CHANGE_OCRNET_NAME: SEMANTIC_SEGMENTATION_MIOU_METRIC_NAME,
    ModelTemplate.CHANGE_PPYOLOE_PLUS_NAME: BOUNDING_BOX_MEAN_AVERAGE_PRECISION_METRIC_NAME,
    ModelTemplate.SVTR_LCNET_NAME: OCR_ACCURACY_METRIC_NAME,
    ModelTemplate.DBNET_NAME: HMEAN_METRIC_NAME,
    ModelTemplate.CV_RESNET_NAME: CLASSIFICATION_ACCURACY_METRIC_NAME,
    ModelTemplate.MASKFORMER_NAME: [LOSS_METRIC_NAME, MIOU_METRIC_NAME, PACC_METRIC_NAME],
    ModelTemplate.RESNET_NAME: CLASSIFICATION_ACCURACY_METRIC_NAME,

}

ALGORITH_TO_CONFIG = {
    ModelTemplate.OCRNET_NAME: OCRNetConfig,
    ModelTemplate.PPYOLOE_PLUS_NAME: PPYOLOEPLUSMConfig,
    ModelTemplate.CODETR_NAME: CoDETRConfig,
    ModelTemplate.CHANGE_OCRNET_NAME: OCRNetConfig,
    ModelTemplate.CHANGE_PPYOLOE_PLUS_NAME: PPYOLOEPLUSMConfig,
    ModelTemplate.SVTR_LCNET_NAME: SVTRLCNetConfig,
    ModelTemplate.DBNET_NAME: DBNetConfig,
    ModelTemplate.CV_RESNET_NAME: ResNetConfig,
    ModelTemplate.MASKFORMER_NAME: OCRNetConfig,
    # ModelTemplate.YOLOSEG_NAME: "Image/InstanceSegmentation",
    ModelTemplate.RESNET_NAME: ResNetConfig,

}
